==> efl-docs-1.20.6-1-x86_64.pkg.tar.xz: usr/share/doc/efl/html/menudata.js <==
/*
@ @licstart  The following is the entire license notice for the
JavaScript code in this file.

Copyright (C) 1997-2017 by Dimitri van Heesch

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

@licend  The above is the entire license notice
for the JavaScript code in this file
*/
var menudata={children:[
{text:"Main Page",url:"index.html"},
{text:"Related Pages",url:"pages.html"},
{text:"Modules",url:"modules.html"},
{text:"Namespaces",url:"namespaces.html",children:[
{text:"Namespace List",url:"namespaces.html"},
{text:"Namespace Members",url:"namespacemembers.html",children:[
{text:"All",url:"namespacemembers.html"},
{text:"Variables",url:"namespacemembers_vars.html"}]}]},
{text:"Data Structures",url:"annotated.html",children:[
{text:"Data Structures",url:"annotated.html"},
{text:"Data Structure Index",url:"classes.html"},
{text:"Class Hierarchy",url:"hierarchy.html"},
{text:"Data Fields",url:"functions.html",children:[
{text:"All",url:"functions.html",children:[
{text:"_",url:"functions.html#index__"},
{text:"a",url:"functions_a.html#index_a"},
{text:"b",url:"functions_b.html#index_b"},
{text:"c",url:"functions_c.html#index_c"},
{text:"d",url:"functions_d.html#index_d"},
{text:"e",url:"functions_e.html#index_e"},
{text:"f",url:"functions_f.html#index_f"},
{text:"g",url:"functions_g.html#index_g"},
{text:"h",url:"functions_h.html#index_h"},
{text:"i",url:"functions_i.html#index_i"},
{text:"j",url:"functions_j.html#index_j"},
{text:"k",url:"functions_k.html#index_k"},
{text:"l",url:"functions_l.html#index_l"},
{text:"m",url:"functions_m.html#index_m"},
{text:"n",url:"functions_n.html#index_n"},
{text:"o",url:"functions_o.html#index_o"},
{text:"p",url:"functions_p.html#index_p"},
{text:"q",url:"functions_q.html#index_q"},
{text:"r",url:"functions_r.html#index_r"},
{text:"s",url:"functions_s.html#index_s"},
{text:"t",url:"functions_t.html#index_t"},
{text:"u",url:"functions_u.html#index_u"},
{text:"v",url:"functions_v.html#index_v"},
{text:"w",url:"functions_w.html#index_w"},
{text:"x",url:"functions_x.html#index_x"},
{text:"y",url:"functions_y.html#index_y"},
{text:"z",url:"functions_z.html#index_z"},
{text:"~",url:"functions_0x7e.html#index_0x7e"}]},
{text:"Functions",url:"functions_func.html",children:[
{text:"_",url:"functions_func.html#index__"},
{text:"a",url:"functions_func_a.html#index_a"},
{text:"b",url:"functions_func_b.html#index_b"},
{text:"c",url:"functions_func_c.html#index_c"},
{text:"d",url:"functions_func_d.html#index_d"},
{text:"e",url:"functions_func_e.html#index_e"},
{text:"f",url:"functions_func_f.html#index_f"},
{text:"g",url:"functions_func_g.html#index_g"},
{text:"h",url:"functions_func_h.html#index_h"},
{text:"i",url:"functions_func_i.html#index_i"},
{text:"j",url:"functions_func_j.html#index_j"},
{text:"l",url:"functions_func_l.html#index_l"},
{text:"m",url:"functions_func_m.html#index_m"},
{text:"n",url:"functions_func_n.html#index_n"},
{text:"o",url:"functions_func_o.html#index_o"},
{text:"p",url:"functions_func_p.html#index_p"},
{text:"r",url:"functions_func_r.html#index_r"},
{text:"s",url:"functions_func_s.html#index_s"},
{text:"t",url:"functions_func_t.html#index_t"},
{text:"u",url:"functions_func_u.html#index_u"},
{text:"v",url:"functions_func_v.html#index_v"},
{text:"w",url:"functions_func_w.html#index_w"},
{text:"~",url:"functions_func_0x7e.html#index_0x7e"}]},
{text:"Variables",url:"functions_vars.html",children:[
{text:"_",url:"functions_vars.html#index__"},
{text:"a",url:"functions_vars_a.html#index_a"},
{text:"b",url:"functions_vars_b.html#index_b"},
{text:"c",url:"functions_vars_c.html#index_c"},
{text:"d",url:"functions_vars_d.html#index_d"},
{text:"e",url:"functions_vars_e.html#index_e"},
{text:"f",url:"functions_vars_f.html#index_f"},
{text:"g",url:"functions_vars_g.html#index_g"},
{text:"h",url:"functions_vars_h.html#index_h"},
{text:"i",url:"functions_vars_i.html#index_i"},
{text:"j",url:"functions_vars_j.html#index_j"},
{text:"k",url:"functions_vars_k.html#index_k"},
{text:"l",url:"functions_vars_l.html#index_l"},
{text:"m",url:"functions_vars_m.html#index_m"},
{text:"n",url:"functions_vars_n.html#index_n"},
{text:"o",url:"functions_vars_o.html#index_o"},
{text:"p",url:"functions_vars_p.html#index_p"},
{text:"q",url:"functions_vars_q.html#index_q"},
{text:"r",url:"functions_vars_r.html#index_r"},
{text:"s",url:"functions_vars_s.html#index_s"},
{text:"t",url:"functions_vars_t.html#index_t"},
{text:"u",url:"functions_vars_u.html#index_u"},
{text:"v",url:"functions_vars_v.html#index_v"},
{text:"w",url:"functions_vars_w.html#index_w"},
{text:"x",url:"functions_vars_x.html#index_x"},
{text:"y",url:"functions_vars_y.html#index_y"},
{text:"z",url:"functions_vars_z.html#index_z"}]},
{text:"Typedefs",url:"functions_type.html",children:[
{text:"_",url:"functions_type.html#index__"},
{text:"a",url:"functions_type.html#index_a"},
{text:"c",url:"functions_type.html#index_c"},
{text:"d",url:"functions_type.html#index_d"},
{text:"i",url:"functions_type.html#index_i"},
{text:"k",url:"functions_type.html#index_k"},
{text:"m",url:"functions_type.html#index_m"},
{text:"n",url:"functions_type.html#index_n"},
{text:"p",url:"functions_type.html#index_p"},
{text:"r",url:"functions_type.html#index_r"},
{text:"s",url:"functions_type.html#index_s"},
{text:"t",url:"functions_type.html#index_t"},
{text:"v",url:"functions_type.html#index_v"}]},
{text:"Related Functions",url:"functions_rela.html"}]}]},
{text:"Files",url:"files.html",children:[
{text:"File List",url:"files.html"},
{text:"Globals",url:"globals.html",children:[
{text:"All",url:"globals.html",children:[
{text:"_",url:"globals.html#index__"},
{text:"a",url:"globals_a.html#index_a"},
{text:"b",url:"globals_b.html#index_b"},
{text:"c",url:"globals_c.html#index_c"},
{text:"d",url:"globals_d.html#index_d"},
{text:"e",url:"globals_e.html#index_e"},
{text:"f",url:"globals_f.html#index_f"},
{text:"g",url:"globals_g.html#index_g"},
{text:"h",url:"globals_h.html#index_h"},
{text:"i",url:"globals_i.html#index_i"},
{text:"k",url:"globals_k.html#index_k"},
{text:"l",url:"globals_l.html#index_l"},
{text:"m",url:"globals_m.html#index_m"},
{text:"n",url:"globals_n.html#index_n"},
{text:"o",url:"globals_o.html#index_o"},
{text:"p",url:"globals_p.html#index_p"},
{text:"q",url:"globals_q.html#index_q"},
{text:"r",url:"globals_r.html#index_r"},
{text:"s",url:"globals_s.html#index_s"},
{text:"t",url:"globals_t.html#index_t"},
{text:"u",url:"globals_u.html#index_u"},
{text:"v",url:"globals_v.html#index_v"},
{text:"w",url:"globals_w.html#index_w"},
{text:"x",url:"globals_x.html#index_x"}]},
{text:"Functions",url:"globals_func.html",children:[
{text:"a",url:"globals_func.html#index_a"},
{text:"b",url:"globals_func_b.html#index_b"},
{text:"c",url:"globals_func_c.html#index_c"},
{text:"d",url:"globals_func_d.html#index_d"},
{text:"e",url:"globals_func_e.html#index_e"},
{text:"f",url:"globals_func_f.html#index_f"},
{text:"g",url:"globals_func_g.html#index_g"},
{text:"h",url:"globals_func_h.html#index_h"},
{text:"i",url:"globals_func_i.html#index_i"},
{text:"l",url:"globals_func_l.html#index_l"},
{text:"m",url:"globals_func_m.html#index_m"},
{text:"n",url:"globals_func_n.html#index_n"},
{text:"o",url:"globals_func_o.html#index_o"},
{text:"p",url:"globals_func_p.html#index_p"},
{text:"q",url:"globals_func_q.html#index_q"},
{text:"r",url:"globals_func_r.html#index_r"},
{text:"s",url:"globals_func_s.html#index_s"},
{text:"t",url:"globals_func_t.html#index_t"},
{text:"u",url:"globals_func_u.html#index_u"},
{text:"v",url:"globals_func_v.html#index_v"},
{text:"w",url:"globals_func_w.html#index_w"},
{text:"x",url:"globals_func_x.html#index_x"}]},
{text:"Variables",url:"globals_vars.html",children:[
{text:"c",url:"globals_vars.html#index_c"},
{text:"d",url:"globals_vars.html#index_d"},
{text:"e",url:"globals_vars.html#index_e"},
{text:"m",url:"globals_vars.html#index_m"},
{text:"w",url:"globals_vars.html#index_w"},
{text:"x",url:"globals_vars.html#index_x"}]},
{text:"Typedefs",url:"globals_type.html",children:[
{text:"a",url:"globals_type.html#index_a"},
{text:"b",url:"globals_type.html#index_b"},
{text:"c",url:"globals_type.html#index_c"},
{text:"d",url:"globals_type.html#index_d"},
{text:"e",url:"globals_type.html#index_e"},
{text:"f",url:"globals_type.html#index_f"},
{text:"i",url:"globals_type.html#index_i"},
{text:"k",url:"globals_type.html#index_k"},
{text:"m",url:"globals_type.html#index_m"},
{text:"n",url:"globals_type.html#index_n"},
{text:"o",url:"globals_type.html#index_o"},
{text:"p",url:"globals_type.html#index_p"},
{text:"q",url:"globals_type.html#index_q"},
{text:"r",url:"globals_type.html#index_r"},
{text:"s",url:"globals_type.html#index_s"},
{text:"u",url:"globals_type.html#index_u"},
{text:"v",url:"globals_type.html#index_v"},
{text:"w",url:"globals_type.html#index_w"},
{text:"x",url:"globals_type.html#index_x"}]},
{text:"Enumerations",url:"globals_enum.html",children:[
{text:"a",url:"globals_enum.html#index_a"},
{text:"b",url:"globals_enum.html#index_b"},
{text:"c",url:"globals_enum.html#index_c"},
{text:"d",url:"globals_enum.html#index_d"},
{text:"e",url:"globals_enum.html#index_e"},
{text:"f",url:"globals_enum.html#index_f"},
{text:"i",url:"globals_enum.html#index_i"},
{text:"m",url:"globals_enum.html#index_m"},
{text:"p",url:"globals_enum.html#index_p"},
{text:"s",url:"globals_enum.html#index_s"},
{text:"u",url:"globals_enum.html#index_u"},
{text:"v",url:"globals_enum.html#index_v"},
{text:"w",url:"globals_enum.html#index_w"},
{text:"x",url:"globals_enum.html#index_x"}]},
{text:"Enumerator",url:"globals_eval.html",children:[
{text:"_",url:"globals_eval.html#index__"},
{text:"a",url:"globals_eval_a.html#index_a"},
{text:"b",url:"globals_eval_b.html#index_b"},
{text:"c",url:"globals_eval_c.html#index_c"},
{text:"d",url:"globals_eval_d.html#index_d"},
{text:"e",url:"globals_eval_e.html#index_e"},
{text:"f",url:"globals_eval_f.html#index_f"},
{text:"h",url:"globals_eval_h.html#index_h"},
{text:"m",url:"globals_eval_m.html#index_m"},
{text:"p",url:"globals_eval_p.html#index_p"},
{text:"r",url:"globals_eval_r.html#index_r"},
{text:"s",url:"globals_eval_s.html#index_s"},
{text:"u",url:"globals_eval_u.html#index_u"},
{text:"v",url:"globals_eval_v.html#index_v"},
{text:"w",url:"globals_eval_w.html#index_w"},
{text:"x",url:"globals_eval_x.html#index_x"}]},
{text:"Macros",url:"globals_defs.html",children:[
{text:"a",url:"globals_defs.html#index_a"},
{text:"b",url:"globals_defs.html#index_b"},
{text:"c",url:"globals_defs.html#index_c"},
{text:"d",url:"globals_defs.html#index_d"},
{text:"e",url:"globals_defs.html#index_e"},
{text:"f",url:"globals_defs.html#index_f"},
{text:"g",url:"globals_defs.html#index_g"},
{text:"h",url:"globals_defs.html#index_h"},
{text:"i",url:"globals_defs.html#index_i"},
{text:"l",url:"globals_defs.html#index_l"},
{text:"m",url:"globals_defs.html#index_m"},
{text:"o",url:"globals_defs.html#index_o"},
{text:"p",url:"globals_defs.html#index_p"},
{text:"r",url:"globals_defs.html#index_r"},
{text:"s",url:"globals_defs.html#index_s"},
{text:"t",url:"globals_defs.html#index_t"},
{text:"v",url:"globals_defs.html#index_v"}]}]}]},
{text:"Examples",url:"examples.html"}]}

==> efl-docs-1.21.1-1-x86_64.pkg.tar.xz: usr/share/doc/efl/html/menudata.js <==
/*
@ @licstart  The following is the entire license notice for the
JavaScript code in this file.

Copyright (C) 1997-2017 by Dimitri van Heesch

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

@licend  The above is the entire license notice
for the JavaScript code in this file
*/
var menudata={children:[
{text:"Main Page",url:"index.html"},
{text:"Related Pages",url:"pages.html"},
{text:"Modules",url:"modules.html"},
{text:"Data Structures",url:"annotated.html",children:[
{text:"Data Structures",url:"annotated.html"},
{text:"Data Structure Index",url:"classes.html"},
{text:"Class Hierarchy",url:"hierarchy.html"},
{text:"Data Fields",url:"functions.html",children:[
{text:"All",url:"functions.html",children:[
{text:"_",url:"functions.html#index__"},
{text:"a",url:"functions_a.html#index_a"},
{text:"b",url:"functions_b.html#index_b"},
{text:"c",url:"functions_c.html#index_c"},
{text:"d",url:"functions_d.html#index_d"},
{text:"e",url:"functions_e.html#index_e"},
{text:"f",url:"functions_f.html#index_f"},
{text:"g",url:"functions_g.html#index_g"},
{text:"h",url:"functions_h.html#index_h"},
{text:"i",url:"functions_i.html#index_i"},
{text:"k",url:"functions_k.html#index_k"},
{text:"l",url:"functions_l.html#index_l"},
{text:"m",url:"functions_m.html#index_m"},
{text:"n",url:"functions_n.html#index_n"},
{text:"o",url:"functions_o.html#index_o"},
{text:"p",url:"functions_p.html#index_p"},
{text:"q",url:"functions_q.html#index_q"},
{text:"r",url:"functions_r.html#index_r"},
{text:"s",url:"functions_s.html#index_s"},
{text:"t",url:"functions_t.html#index_t"},
{text:"u",url:"functions_u.html#index_u"},
{text:"v",url:"functions_v.html#index_v"},
{text:"w",url:"functions_w.html#index_w"},
{text:"x",url:"functions_x.html#index_x"},
{text:"y",url:"functions_y.html#index_y"},
{text:"z",url:"functions_z.html#index_z"}]},
{text:"Functions",url:"functions_func.html"},
{text:"Variables",url:"functions_vars.html",children:[
{text:"_",url:"functions_vars.html#index__"},
{text:"a",url:"functions_vars_a.html#index_a"},
{text:"b",url:"functions_vars_b.html#index_b"},
{text:"c",url:"functions_vars_c.html#index_c"},
{text:"d",url:"functions_vars_d.html#index_d"},
{text:"e",url:"functions_vars_e.html#index_e"},
{text:"f",url:"functions_vars_f.html#index_f"},
{text:"g",url:"functions_vars_g.html#index_g"},
{text:"h",url:"functions_vars_h.html#index_h"},
{text:"i",url:"functions_vars_i.html#index_i"},
{text:"k",url:"functions_vars_k.html#index_k"},
{text:"l",url:"functions_vars_l.html#index_l"},
{text:"m",url:"functions_vars_m.html#index_m"},
{text:"n",url:"functions_vars_n.html#index_n"},
{text:"o",url:"functions_vars_o.html#index_o"},
{text:"p",url:"functions_vars_p.html#index_p"},
{text:"q",url:"functions_vars_q.html#index_q"},
{text:"r",url:"functions_vars_r.html#index_r"},
{text:"s",url:"functions_vars_s.html#index_s"},
{text:"t",url:"functions_vars_t.html#index_t"},
{text:"u",url:"functions_vars_u.html#index_u"},
{text:"v",url:"functions_vars_v.html#index_v"},
{text:"w",url:"functions_vars_w.html#index_w"},
{text:"x",url:"functions_vars_x.html#index_x"},
{text:"y",url:"functions_vars_y.html#index_y"},
{text:"z",url:"functions_vars_z.html#index_z"}]}]}]},
{text:"Files",url:"files.html",children:[
{text:"File List",url:"files.html"},
{text:"Globals",url:"globals.html",children:[
{text:"All",url:"globals.html",children:[
{text:"_",url:"globals.html#index__"},
{text:"a",url:"globals_a.html#index_a"},
{text:"b",url:"globals_b.html#index_b"},
{text:"c",url:"globals_c.html#index_c"},
{text:"d",url:"globals_d.html#index_d"},
{text:"e",url:"globals_e.html#index_e"},
{text:"f",url:"globals_f.html#index_f"},
{text:"g",url:"globals_g.html#index_g"},
{text:"h",url:"globals_h.html#index_h"},
{text:"i",url:"globals_i.html#index_i"},
{text:"k",url:"globals_k.html#index_k"},
{text:"l",url:"globals_l.html#index_l"},
{text:"m",url:"globals_m.html#index_m"},
{text:"n",url:"globals_n.html#index_n"},
{text:"o",url:"globals_o.html#index_o"},
{text:"p",url:"globals_p.html#index_p"},
{text:"q",url:"globals_q.html#index_q"},
{text:"r",url:"globals_r.html#index_r"},
{text:"s",url:"globals_s.html#index_s"},
{text:"t",url:"globals_t.html#index_t"},
{text:"u",url:"globals_u.html#index_u"},
{text:"v",url:"globals_v.html#index_v"},
{text:"w",url:"globals_w.html#index_w"},
{text:"x",url:"globals_x.html#index_x"}]},
{text:"Functions",url:"globals_func.html",children:[
{text:"a",url:"globals_func.html#index_a"},
{text:"b",url:"globals_func_b.html#index_b"},
{text:"c",url:"globals_func_c.html#index_c"},
{text:"d",url:"globals_func_d.html#index_d"},
{text:"e",url:"globals_func_e.html#index_e"},
{text:"f",url:"globals_func_f.html#index_f"},
{text:"g",url:"globals_func_g.html#index_g"},
{text:"h",url:"globals_func_h.html#index_h"},
{text:"i",url:"globals_func_i.html#index_i"},
{text:"l",url:"globals_func_l.html#index_l"},
{text:"m",url:"globals_func_m.html#index_m"},
{text:"n",url:"globals_func_n.html#index_n"},
{text:"o",url:"globals_func_o.html#index_o"},
{text:"p",url:"globals_func_p.html#index_p"},
{text:"q",url:"globals_func_q.html#index_q"},
{text:"r",url:"globals_func_r.html#index_r"},
{text:"s",url:"globals_func_s.html#index_s"},
{text:"t",url:"globals_func_t.html#index_t"},
{text:"u",url:"globals_func_u.html#index_u"},
{text:"v",url:"globals_func_v.html#index_v"},
{text:"w",url:"globals_func_w.html#index_w"},
{text:"x",url:"globals_func_x.html#index_x"}]},
{text:"Variables",url:"globals_vars.html",children:[
{text:"c",url:"globals_vars.html#index_c"},
{text:"d",url:"globals_vars.html#index_d"},
{text:"e",url:"globals_vars.html#index_e"},
{text:"m",url:"globals_vars.html#index_m"},
{text:"w",url:"globals_vars.html#index_w"},
{text:"x",url:"globals_vars.html#index_x"}]},
{text:"Typedefs",url:"globals_type.html",children:[
{text:"a",url:"globals_type.html#index_a"},
{text:"b",url:"globals_type.html#index_b"},
{text:"c",url:"globals_type.html#index_c"},
{text:"d",url:"globals_type.html#index_d"},
{text:"e",url:"globals_type.html#index_e"},
{text:"f",url:"globals_type.html#index_f"},
{text:"i",url:"globals_type.html#index_i"},
{text:"k",url:"globals_type.html#index_k"},
{text:"m",url:"globals_type.html#index_m"},
{text:"n",url:"globals_type.html#index_n"},
{text:"o",url:"globals_type.html#index_o"},
{text:"p",url:"globals_type.html#index_p"},
{text:"q",url:"globals_type.html#index_q"},
{text:"r",url:"globals_type.html#index_r"},
{text:"s",url:"globals_type.html#index_s"},
{text:"u",url:"globals_type.html#index_u"},
{text:"v",url:"globals_type.html#index_v"},
{text:"w",url:"globals_type.html#index_w"},
{text:"x",url:"globals_type.html#index_x"}]},
{text:"Enumerations",url:"globals_enum.html",children:[
{text:"a",url:"globals_enum.html#index_a"},
{text:"b",url:"globals_enum.html#index_b"},
{text:"c",url:"globals_enum.html#index_c"},
{text:"d",url:"globals_enum.html#index_d"},
{text:"e",url:"globals_enum.html#index_e"},
{text:"f",url:"globals_enum.html#index_f"},
{text:"i",url:"globals_enum.html#index_i"},
{text:"m",url:"globals_enum.html#index_m"},
{text:"p",url:"globals_enum.html#index_p"},
{text:"s",url:"globals_enum.html#index_s"},
{text:"u",url:"globals_enum.html#index_u"},
{text:"v",url:"globals_enum.html#index_v"},
{text:"w",url:"globals_enum.html#index_w"},
{text:"x",url:"globals_enum.html#index_x"}]},
{text:"Enumerator",url:"globals_eval.html",children:[
{text:"_",url:"globals_eval.html#index__"},
{text:"a",url:"globals_eval_a.html#index_a"},
{text:"b",url:"globals_eval_b.html#index_b"},
{text:"c",url:"globals_eval_c.html#index_c"},
{text:"d",url:"globals_eval_d.html#index_d"},
{text:"e",url:"globals_eval_e.html#index_e"},
{text:"f",url:"globals_eval_f.html#index_f"},
{text:"h",url:"globals_eval_h.html#index_h"},
{text:"m",url:"globals_eval_m.html#index_m"},
{text:"p",url:"globals_eval_p.html#index_p"},
{text:"r",url:"globals_eval_r.html#index_r"},
{text:"s",url:"globals_eval_s.html#index_s"},
{text:"u",url:"globals_eval_u.html#index_u"},
{text:"v",url:"globals_eval_v.html#index_v"},
{text:"w",url:"globals_eval_w.html#index_w"},
{text:"x",url:"globals_eval_x.html#index_x"}]},
{text:"Macros",url:"globals_defs.html",children:[
{text:"a",url:"globals_defs.html#index_a"},
{text:"b",url:"globals_defs.html#index_b"},
{text:"c",url:"globals_defs.html#index_c"},
{text:"d",url:"globals_defs.html#index_d"},
{text:"e",url:"globals_defs.html#index_e"},
{text:"f",url:"globals_defs.html#index_f"},
{text:"g",url:"globals_defs.html#index_g"},
{text:"h",url:"globals_defs.html#index_h"},
{text:"i",url:"globals_defs.html#index_i"},
{text:"l",url:"globals_defs.html#index_l"},
{text:"m",url:"globals_defs.html#index_m"},
{text:"o",url:"globals_defs.html#index_o"},
{text:"p",url:"globals_defs.html#index_p"},
{text:"r",url:"globals_defs.html#index_r"},
{text:"s",url:"globals_defs.html#index_s"},
{text:"t",url:"globals_defs.html#index_t"},
{text:"v",url:"globals_defs.html#index_v"}]}]}]},
{text:"Examples",url:"examples.html"}]}
